Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(549)

Unified Diff: ui/ozone/platform/dri/hardware_display_controller.cc

Issue 106633002: GBM Ozone implementation (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/ozone/platform/dri/hardware_display_controller.cc
diff --git a/ui/ozone/platform/dri/hardware_display_controller.cc b/ui/ozone/platform/dri/hardware_display_controller.cc
index 6256aee2b28d17dc214ef63e3a7b442a3bb0d26a..e6ce1f5642bd7b8f7af096e8b0d10d0b88701be6 100644
--- a/ui/ozone/platform/dri/hardware_display_controller.cc
+++ b/ui/ozone/platform/dri/hardware_display_controller.cc
@@ -15,9 +15,10 @@
#include "base/time/time.h"
#include "third_party/skia/include/core/SkCanvas.h"
#include "ui/gfx/geometry/point.h"
+#include "ui/gfx/geometry/size.h"
#include "ui/ozone/platform/dri/dri_buffer.h"
-#include "ui/ozone/platform/dri/dri_surface.h"
#include "ui/ozone/platform/dri/dri_wrapper.h"
+#include "ui/ozone/platform/dri/scanout_surface.h"
namespace ui {
@@ -28,7 +29,7 @@ namespace {
// The old frontbuffer is no longer used by the hardware and can be used for
// future draw operations.
//
// |device| will contain a reference to the |DriSurface| object which
// the event belongs to.
//
// TODO(dnicoara) When we have a FD handler for the DRM calls in the message
@@ -63,7 +64,7 @@ HardwareDisplayController::~HardwareDisplayController() {
bool
HardwareDisplayController::BindSurfaceToController(
- scoped_ptr<DriSurface> surface, drmModeModeInfo mode) {
+ scoped_ptr<ScanoutSurface> surface, drmModeModeInfo mode) {
CHECK(surface);
if (!drm_->SetCrtc(crtc_id_,
@@ -94,7 +95,6 @@ void HardwareDisplayController::Disable() {
bool HardwareDisplayController::SchedulePageFlip() {
CHECK(surface_);
-
if (!drm_->PageFlip(crtc_id_,
surface_->GetFramebufferId(),
this)) {
@@ -127,11 +127,11 @@ void HardwareDisplayController::OnPageFlipEvent(unsigned int frame,
surface_->SwapBuffers();
}
-bool HardwareDisplayController::SetCursor(DriSurface* surface) {
+bool HardwareDisplayController::SetCursor(ScanoutSurface* surface) {
bool ret = drm_->SetCursor(crtc_id_,
surface->GetHandle(),
- surface->size().width(),
- surface->size().height());
+ surface->Size().width(),
+ surface->Size().height());
surface->SwapBuffers();
return ret;
}
@@ -28,7 +29,7 @@ namespace {
// future draw operations.
//
-// |device| will contain a reference to the |DriSurface| object which
+// |device| will contain a reference to the |ScanoutSurface| object which
// the event belongs to.
//
« no previous file with comments | « ui/ozone/platform/dri/hardware_display_controller.h ('k') | ui/ozone/platform/dri/hardware_display_controller_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698